@@ -13,6 +13,21 @@ from impactEffects.instances.TargetClass import *
 from impactEffects.core.config import *
 
 
+def collins_cal_mass(impactor: Impactor) -> float:
+    """
+
+    Arguments
+    ---------
+    impactor: Instance of Impactor, containning
+
+    Returns
+    -------
+
+    """
+
+    return impactor.get_mass()
+
+
 def collins_kinetic_energy(impactor: Impactor) -> float:
     """
 
@@ -149,7 +164,7 @@ def collins_burst_velocity_at_zero(
         return 0
 
     # Burst altitude is zero
-    altitudeBurst = 0
+    impactor.altitudeBurst = 0
     # Define the terminal velocity
     # Assuming drag coefficient of 2
     _vTerminal = min(
@@ -195,9 +210,7 @@ def collins_altitude_of_breakup(
     """
 
     if collins_iFactor == 0 or rStrength == 0:
-        collins_iFactor, av, rStrength = collins_cal_iFactor(
-            impactor, target
-        )
+        collins_iFactor, av, rStrength = collins_cal_iFactor(impactor, target)
 
     # check
     if collins_iFactor >= 1:
@@ -209,9 +222,7 @@ def collins_altitude_of_breakup(
 
     # Define the second, third and fourth terms (inside the brackets) in Eq. 11
     omega = (
-        1.308
-        - 0.314 * collins_iFactor
-        - 1.303 * (1 - collins_iFactor) ** 0.5
+        1.308 - 0.314 * collins_iFactor - 1.303 * (1 - collins_iFactor) ** 0.5
     )
 
     # Compute the breakup altitude by
@@ -222,10 +233,7 @@ def collins_altitude_of_breakup(
 
 
 def collins_velocity_at_breakup(
-    impactor: Impactor,
-    target: Target,
-    av: float = 0,
-    altitudeBU: float = 0,
+    impactor: Impactor, target: Target, av: float = 0, altitudeBU: float = 0,
 ) -> float:
     """
 
@@ -238,9 +246,7 @@ def collins_velocity_at_breakup(
 
     """
     if av == 0 or altitudeBU == 0:
-        collins_iFactor, av, rStrength = collins_cal_iFactor(
-            impactor, target
-        )
+        collins_iFactor, av, rStrength = collins_cal_iFactor(impactor, target)
 
         # check
         if collins_iFactor >= 1:
@@ -278,9 +284,7 @@ def collins_dispersion_length_scale(
 
     """
     if collins_iFactor == 0:
-        collins_iFactor, av, rStrength = collins_cal_iFactor(
-            impactor, target
-        )
+        collins_iFactor, av, rStrength = collins_cal_iFactor(impactor, target)
     # check
     if collins_iFactor >= 1:
         # logging.warning("I_factor should be greater than 1!")
@@ -317,9 +321,7 @@ def collins_airburst_altitude(
 
     """
     if collins_iFactor == 0:
-        collins_iFactor, av, rStrength = collins_cal_iFactor(
-            impactor, target
-        )
+        collins_iFactor, av, rStrength = collins_cal_iFactor(impactor, target)
     # check
     if collins_iFactor >= 1:
         # logging.warning("I_factor should be greater than 1!")
@@ -332,9 +334,7 @@ def collins_airburst_altitude(
         )
 
     if lDisper == 0:
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
     if alpha2 == 0:
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
@@ -345,8 +345,12 @@ def collins_airburst_altitude(
         * target.get_schaleHeight()
         * log(1 + alpha2 * lDisper / (2 * target.get_schaleHeight()))
     )
-    altitudeBurst = altitudeBU - altitudePen
-    return altitudeBurst
+    impactor.altitudeBurst = altitudeBU - altitudePen
+
+    if impactor.altitudeBurst <= 0:
+        impactor.altitudeBurst = 0
+
+    return impactor.altitudeBurst
 
 
 def collins_brust_velocity(
@@ -369,9 +373,7 @@ def collins_brust_velocity(
 
     """
     if collins_iFactor == 0:
-        collins_iFactor, av, rStrength = collins_cal_iFactor(
-            impactor, target
-        )
+        collins_iFactor, av, rStrength = collins_cal_iFactor(impactor, target)
     # check
     if collins_iFactor >= 1:
         # logging.warning("I_factor should be greater than 1!")
@@ -388,13 +390,11 @@ def collins_brust_velocity(
         vBu = collins_velocity_at_breakup(impactor, target, _av, altitudeBU)
 
     if lDisper == 0:
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
     alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
     if altitudeBurst == 0:
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
@@ -411,7 +411,7 @@ def collins_brust_velocity(
     )  # Assuming drag coefficient of 2
 
     # print("vBU: ", vBu)
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # Evaluate Eq. 19 (without factor lL_0^2 l_disper * pdiameter**2)
         expfac = (
             1
@@ -455,7 +455,7 @@ def collins_brust_velocity(
     return velocity / 1000
 
 
-def collins_cal_velocity(impactor: Impactor, target: Target,) -> float:
+def collins_cal_velocity(impactor: Impactor, target: Target) -> float:
     i_factor, _av, _rStrength = collins_cal_iFactor(impactor, target)
 
     if i_factor >= 1:
@@ -464,9 +464,7 @@ def collins_cal_velocity(impactor: Impactor, target: Target,) -> float:
         )
     else:
         return collins_brust_velocity(
-            impactor=impactor,
-            target=target,
-            collins_iFactor=i_factor,
+            impactor=impactor, target=target, collins_iFactor=i_factor,
         )
 
 
@@ -558,6 +556,65 @@ def collins_fraction_of_momentum(
     return lratio, pratio
 
 
+def collins_cal_linmom(
+    impactor: Impactor, target: Target, velocity: float = 0
+):
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if velocity == 0:
+        velocity = collins_cal_velocity(impactor, target)
+
+    linmom = impactor.get_mass() * (velocity * 1000)
+
+    # relativistic effects, multiply energy by 1/sqrt(1 - v^2/c^2)
+    if impactor.get_velocity() > (0.25 * 3 * 10 ** 5):
+        beta = 1 / (1 - impactor.get_velocity() ** 2 / 9 * 10 ** 10) ** 0.5
+        linmom *= beta
+
+    return linmom
+
+
+def collins_cal_angmom(
+    impactor: Impactor, target: Target, velocity: float = 0
+):
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if velocity == 0:
+        velocity = collins_cal_velocity(impactor, target)
+
+    angmom = (
+        impactor.get_mass()
+        * (velocity * 1000)
+        * cos(impactor.get_theta() * PI / 180)
+        * target.get_R_earth()
+    )
+
+    # relativistic effects, multiply energy by 1/sqrt(1 - v^2/c^2)
+    if impactor.get_velocity() > (0.25 * 3 * 10 ** 5):
+        beta = 1 / (1 - impactor.get_velocity() ** 2 / 9 * 10 ** 10) ** 0.5
+        angmom *= beta
+
+    return angmom
+
+
 def collins_cal_trot_change(
     impactor: Impactor, target: Target, velocity: float = 0
 ):
@@ -638,12 +695,10 @@ def collins_cal_energy_blast_surface(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
         velocity = collins_cal_velocity(impactor, target)
@@ -653,12 +708,12 @@ def collins_cal_energy_blast_surface(
             impactor, target, velocity
         )
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # Blast energy is airburst energy (kTons)
         energy_blast = energy_atmosphere / (4.186 * 10 ** 12)
         energy_surface = energy_atmosphere
     else:
-        altitudeBurst = 0
+        impactor.altitudeBurst = 0
         energy_surface = 0.5 * impactor.get_mass() * (velocity * 1000) ** 2
         # Blast energy is larger of airburt and impact energy (kTons)
         if energy_atmosphere > energy_surface:
@@ -852,14 +907,23 @@ def collins_cal_transient_crater_diameter(
     if Cd == 0 or beta == 0:
         Cd, beta = collins_cal_scaling_diameter_constant(target=target)
 
+    # # print("-----collins_cal_transient_crater_diameter----",
+    #       "Cd: %f, beta: %f" % (Cd, beta))
+
     if anglefac == 0:
         anglefac = collins_cal_anglefac(impactor)
+    # # print("-----collins_cal_transient_crater_diameter----",
+    #       "anglefac: %f" % (anglefac))
 
     if vseafloor == 0:
         vseafloor = collins_cal_velocity_projectile(impactor, target)
+    # # print("-----collins_cal_transient_crater_diameter----",
+    #       "vseafloor: %f" % (vseafloor))
 
     if dispersion == 0:
         dispersion = collins_dispersion_of_impactor(impactor, target)
+    # print("-----collins_cal_transient_crater_diameter----",
+    #       "dispersion: ", dispersion)
 
     mass, g, pdiameter = (
         impactor.get_mass(),
@@ -871,6 +935,8 @@ def collins_cal_transient_crater_diameter(
         tdensity = target.seefloor_density
     else:
         tdensity = target.density
+    # print("-----collins_cal_transient_crater_diameter----",
+    #       "tdensity: %f" % (tdensity))
 
     # print(
     #     "mass: {, tdensity: {, g: {, pdiameter: {".format(
@@ -910,9 +976,7 @@ def collins_cal_depthr(impactor: Impactor, target: Target, Dtr: float = 0):
     return Dtr / 2.828
 
 
-def collins_cal_cdiamater(
-    impactor: Impactor, target: Target, Dtr: float = 0
-):
+def collins_cal_cdiamater(impactor: Impactor, target: Target, Dtr: float = 0):
     """
 
     Arguments
@@ -926,6 +990,7 @@ def collins_cal_cdiamater(
     if Dtr == 0:
         Dtr = collins_cal_transient_crater_diameter(impactor, target)
 
+    # print("------IN----collins_cal_cdiamater------Dtr: ", Dtr)
     if Dtr * 1.25 >= 3200:
         cdiameter = (1.17 * Dtr ** 1.13) / (3200 ** 0.13)
     else:
@@ -1157,16 +1222,14 @@ def collins_cal_eject_arrival(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
         return 0
 
@@ -1179,8 +1242,7 @@ def collins_cal_eject_arrival(
     )  # semi major axis of elliptical path
 
     part1 = (
-        a ** 1.5
-        / (target.get_g() * (target.get_R_earth() * 1000) ** 2) ** 0.5
+        a ** 1.5 / (target.get_g() * (target.get_R_earth() * 1000) ** 2) ** 0.5
     )
     term1 = 2 * atan(((1 - e) / (1 + e)) ** 0.5 * tan(phi / 2))
     term2 = e * (1 - e ** 2) ** 0.5 * sin(phi) / (1 + e * cos(phi))
@@ -1210,26 +1272,22 @@ def collins_cal_ejecta_thickness(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
     if Dtr == 0:
         Dtr = collins_cal_transient_crater_diameter(impactor, target)
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
         return 0
 
     # print("Dtr: ", Dtr, " distance: ", target.distance)
-    ejecta_thickness = Dtr ** 4 / (
-        112 * (target.get_distance() * 1000) ** 3
-    )
+    ejecta_thickness = Dtr ** 4 / (112 * (target.get_distance() * 1000) ** 3)
     return ejecta_thickness
 
 
@@ -1246,16 +1304,14 @@ def collins_cal_d_frag(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
         exit(1)
 
@@ -1300,12 +1356,10 @@ def collins_cal_themal(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
@@ -1313,14 +1367,12 @@ def collins_cal_themal(
         velocity = collins_cal_velocity(impactor, target,)
 
     if energy_surface == 0:
-        _, energy_surface = collins_cal_energy_blast_surface(
-            impactor, target
-        )
+        _, energy_surface = collins_cal_energy_blast_surface(impactor, target)
 
     if delta == 0:
         delta = collins_cal_ePIcentral_angle(target=target)
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
 
         return (
@@ -1331,6 +1383,7 @@ def collins_cal_themal(
             0,
             0,
             0,
+            0,
         )
 
     energy_megatons = energy_surface / (4.186 * 10 ** 15)
@@ -1399,19 +1452,17 @@ def collins_cal_magnitude(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
     if energy_seafloor == 0:
         energy_seafloor = collins_cal_energy_at_seafloor(impactor, target)
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
         return 0
 
@@ -1441,12 +1492,10 @@ def collins_cal_magnitude2(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
@@ -1456,7 +1505,7 @@ def collins_cal_magnitude2(
     if delta == 0:
         delta = collins_cal_ePIcentral_angle(target=target)
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         # logging.warning("Altitude of burst is greater than 0")
         return 0, 0
 
@@ -1464,7 +1513,7 @@ def collins_cal_magnitude2(
     magnitude = collins_cal_magnitude(
         impactor,
         target,
-        altitudeBurst=altitudeBurst,
+        altitudeBurst=impactor.altitudeBurst,
         energy_seafloor=energy_seafloor,
     )
     distance = target.distance
@@ -1503,13 +1552,12 @@ def collins_cal_shock_arrival(
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
+        # print("i_factor: ", i_factor)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
-            impactor, target, alpha2, lDisper, altitudeBU
+        impactor.altitudeBurst = collins_airburst_altitude(
+            impactor, target, alpha2, lDisper, altitudeBU, i_factor
         )
 
     vsound = 330  # speed of sound in m/s
@@ -1518,10 +1566,13 @@ def collins_cal_shock_arrival(
     # Arrival time is straight line distance divided by sound speed
     # for air burst, distance is slant range from explosion
     slantRange = (
-        target.get_distance() ** 2 + (altitudeBurst / 1000) ** 2
+        target.get_distance() ** 2 + (impactor.altitudeBurst / 1000) ** 2
     ) ** (1 / 2)
     # distance in meters divided by velocity of sound in m/s
     shock_arrival = (slantRange * 1000) / vsound
+    # print("distance: ", target.get_distance())
+    # print("altitudeBurst: ", impactor.altitudeBurst)
+    # print("slantRange: ", slantRange)
 
     return shock_arrival
 
@@ -1542,23 +1593,21 @@ def collins_cal_vmax(
     -------
 
     """
-    if altitudeBurst == 0:
+    if impactor.altitudeBurst == 0:
         i_factor, _av, _rStrength = collins_cal_iFactor(impactor, target)
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
     if energy_blast == 0:
         energy_blast, _ = collins_cal_energy_blast_surface(
-            impactor, target, altitudeBurst=altitudeBurst
+            impactor, target, altitudeBurst=impactor.altitudeBurst
         )
 
     Po = target.get_Po()
@@ -1583,13 +1632,13 @@ def collins_cal_vmax(
     d_scale = (target.get_distance() * 1000) / sf
 
     # Scale burst altitude to equivalent for a kiloton explosion
-    z_scale = altitudeBurst / sf
+    z_scale = impactor.altitudeBurst / sf
     r_cross = r_cross0 + 0.65 * z_scale
     r_mach = 550 * z_scale / (1.2 * (550 - z_scale))
     if z_scale >= 550:
         r_mach = 1e30
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         d_smooth = z_scale ** 2 * 0.00328
         p_machT = (
             ((r_cross * op_cross) / 4)
@@ -1631,10 +1680,7 @@ def collins_cal_vmax(
 
 
 def collins_cal_shock_damage(
-    impactor: Impactor,
-    target: Target,
-    opressure: float = 0,
-    vmax: float = 0,
+    impactor: Impactor, target: Target, opressure: float = 0, vmax: float = 0,
 ) -> float:
     """
 
@@ -1721,23 +1767,21 @@ def collins_cal_dec_level(
     -------
 
     """
-    if altitudeBurst == 0:
+    if impactor.altitudeBurst == 0:
         i_factor, _av, _rStrength = collins_cal_iFactor(impactor, target)
         altitudeBU = collins_altitude_of_breakup(
             impactor, target, i_factor, _rStrength
         )
-        lDisper = collins_dispersion_length_scale(
-            impactor, target, altitudeBU
-        )
+        lDisper = collins_dispersion_length_scale(impactor, target, altitudeBU)
 
         alpha2 = (target.get_fp() ** 2 - 1) ** (1 / 2)
-        altitudeBurst = collins_airburst_altitude(
+        impactor.altitudeBurst = collins_airburst_altitude(
             impactor, target, alpha2, lDisper, altitudeBU
         )
 
     if energy_blast == 0:
         energy_blast, _ = collins_cal_energy_blast_surface(
-            impactor, target, altitudeBurst=altitudeBurst
+            impactor, target, altitudeBurst=impactor.altitudeBurst
         )
 
     r_cross = 0
@@ -1760,13 +1804,13 @@ def collins_cal_dec_level(
     d_scale = (target.get_distance() * 1000) / sf
 
     # Scale burst altitude to equivalent for a kiloton explosion
-    z_scale = altitudeBurst / sf
+    z_scale = impactor.altitudeBurst / sf
     r_cross = r_cross0 + 0.65 * z_scale
     r_mach = 550 * z_scale / (1.2 * (550 - z_scale))
     if z_scale >= 550:
         r_mach = 1e30
 
-    if altitudeBurst > 0:
+    if impactor.altitudeBurst > 0:
         d_smooth = z_scale ** 2 * 0.00328
         p_machT = (
             ((r_cross * op_cross) / 4)
@@ -1860,9 +1904,7 @@ def collins_cal_WaveAmplitudeUpperLimit(
         wdiameter = collins_cal_wdiameter(impactor, target)
 
     MaxWaveAmplitude = 0  # Maximum rim wave amplitude
-    MaxWaveRadius = (
-        0  # Radius where max rim wave is formed (upper estimate)
-    )
+    MaxWaveRadius = 0  # Radius where max rim wave is formed (upper estimate)
     RimWaveExponent = 0  # Attenuation factor for rim wave
 
     # Define parameters
@@ -1896,9 +1938,7 @@ def collins_cal_WaveAmplitudeLowerLimit(
 
     shallowness = 0  # Ratio of Impactor diameter to water depth
     MaxWaveAmplitude = 0  # Maximum rim wave amplitude
-    MinWaveRadius = (
-        0  # Radius where max rim wave is formed (lower estimate)
-    )
+    MinWaveRadius = 0  # Radius where max rim wave is formed (lower estimate)
     CollapseWaveRadius = 0  # Radius where collapse wave is formed
     RimWaveExponent = 0  # Attenuation factor for rim wave
     CollapseWaveExponent = 0  # Attenuation factor for collapse wave
