@@ -14,6 +14,25 @@ from impactEffects.core.core_collins import *
 from impactEffects.utils.print import *
 
 
+def cal_mass(
+    impactor: Impactor, target: Target, type: Choices = Choices.Collins
+) -> float:
+    """
+
+    Arguments
+    ---------
+    impactor: Instance of Impactor, containning
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_mass(impactor)
+
+    return 0
+
+
 def kinetic_energy(
     impactor: Impactor, type: Choices = Choices.Collins
 ) -> float:
@@ -70,6 +89,26 @@ def rec_time(impactor: Impactor, type: Choices = Choices.Collins) -> float:
     return 0
 
 
+def cal_rec_time(
+    impactor: Impactor, target: Target, type: Choices = Choices.Collins
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_rec_time(impactor)
+
+    return 0
+
+
 def iFactor(
     impactor: Impactor, target: Target, type: Choices = Choices.Collins
 ) -> float:
@@ -127,9 +166,7 @@ def altitude_of_breakup(
     """
 
     if type is Choices.Collins:
-        return collins_altitude_of_breakup(
-            impactor, target, collins_iFactor
-        )
+        return collins_altitude_of_breakup(impactor, target, collins_iFactor)
 
     return 0
 
@@ -180,6 +217,28 @@ def dispersion_length_scale(
     return 0
 
 
+def cal_lDisper(
+    impactor: Impactor,
+    target: Target,
+    altitudeBU: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_dispersion_length_scale(impactor, target, altitudeBU)
+
+    return 0
+
+
 def airburst_altitude(
     impactor: Impactor,
     target: Target,
@@ -234,6 +293,33 @@ def brust_velocity(
     return 0
 
 
+def cal_dispersion(
+    impactor: Impactor,
+    target: Target,
+    l_disper: float = 0,
+    altitude_bu: float = 0,
+    altitude_burst: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_dispersion_of_impactor(
+            impactor, target, l_disper, altitude_bu, altitude_burst
+        )
+
+    return 0
+
+
 def dispersion_of_impactor(
     impactor: Impactor,
     target: Target,
@@ -284,6 +370,98 @@ def fraction_of_momentum(
     return 0
 
 
+def cal_pratio(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_fraction_of_momentum(impactor, target, velocity)[1]
+
+    return 0
+
+
+def cal_lratio(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_fraction_of_momentum(impactor, target, velocity)[0]
+
+    return 0
+
+
+def cal_angmom(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_cal_angmom(impactor, target, velocity)
+
+    return 0
+
+
+def cal_linmom(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_cal_linmom(impactor, target, velocity)
+
+    return 0
+
+
 def cal_trot_change(
     impactor: Impactor,
     target: Target,
@@ -356,6 +534,58 @@ def cal_energy_blast_surface(
     return 0
 
 
+def cal_energy_blast(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    altitudeBurst: float = 0,
+    energy_atmosphere: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_energy_blast_surface(
+            impactor, target, velocity, altitudeBurst, energy_atmosphere
+        )[0]
+
+    return 0
+
+
+def cal_energy_surface(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    altitudeBurst: float = 0,
+    energy_atmosphere: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_energy_blast_surface(
+            impactor, target, velocity, altitudeBurst, energy_atmosphere
+        )[1]
+
+    return 0
+
+
 def cal_mass_of_water(
     impactor: Impactor, target: Target, type: Choices = Choices.Collins
 ) -> float:
@@ -376,6 +606,26 @@ def cal_mass_of_water(
     return 0
 
 
+def cal_mwater(
+    impactor: Impactor, target: Target, type: Choices = Choices.Collins
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_cal_mass_of_water(impactor, target)
+
+    return 0
+
+
 def cal_velocity_projectile(
     impactor: Impactor,
     target: Target,
@@ -399,6 +649,15 @@ def cal_velocity_projectile(
     return 0
 
 
+def cal_velocity(
+    impactor: Impactor, target: Target, type: Choices = Choices.Collins,
+) -> float:
+    if type is Choices.Collins:
+        return collins_cal_velocity(impactor, target)
+
+    return 0
+
+
 def cal_energy_at_seafloor(
     impactor: Impactor,
     target: Target,
@@ -421,6 +680,28 @@ def cal_energy_at_seafloor(
     return 0
 
 
+def cal_energy_seafloor(
+    impactor: Impactor,
+    target: Target,
+    vseafloor: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_energy_at_seafloor(impactor, target, vseafloor)
+
+    return 0
+
+
 def cal_ePIcentral_angle(
     target: Target, type: Choices = Choices.Collins
 ) -> float:
@@ -461,9 +742,43 @@ def cal_scaling_diameter_constant(
     return 0
 
 
-def cal_anglefac(
-    impactor: Impactor, type: Choices = Choices.Collins
-) -> float:
+def cal_Cd(target: Target, type: Choices = Choices.Collins) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_cal_scaling_diameter_constant(target=target)[0]
+
+    return 0
+
+
+def cal_beta(target: Target, type: Choices = Choices.Collins) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+
+    if type is Choices.Collins:
+        return collins_cal_scaling_diameter_constant(target=target)[1]
+
+    return 0
+
+
+def cal_anglefac(impactor: Impactor, type: Choices = Choices.Collins) -> float:
     """
 
     Arguments
@@ -553,7 +868,7 @@ def cal_depthr(
     return 0
 
 
-def cal_cdiamater(
+def cal_depthtr(
     impactor: Impactor,
     target: Target,
     Dtr: float = 0,
@@ -565,6 +880,48 @@ def cal_cdiamater(
     ---------
 
 
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_depthr(impactor, target, Dtr)
+
+    return 0
+
+
+def cal_cdiameter(
+    impactor: Impactor,
+    target: Target,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_cdiamater(impactor, target, Dtr)
+
+    return 0
+
+
+def cal_cdiamater(
+    impactor: Impactor,
+    target: Target,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
     Returns
     -------
 
@@ -620,9 +977,7 @@ def cal_depthfr(
 
     """
     if type is Choices.Collins:
-        return collins_cal_depthfr(
-            impactor, target, Dtr, depthtr, cdiameter
-        )
+        return collins_cal_depthfr(impactor, target, Dtr, depthtr, cdiameter)
 
     return 0
 
@@ -694,6 +1049,50 @@ def cal_vCrater_vRation(
     return 0
 
 
+def cal_vCrater(
+    impactor: Impactor,
+    target: Target,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_vCrater_vRation(impactor, target, Dtr)[0]
+
+    return 0
+
+
+def cal_vration(
+    impactor: Impactor,
+    target: Target,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_vCrater_vRation(impactor, target, Dtr)[1]
+
+    return 0
+
+
 def cal_vMelt(
     impactor: Impactor,
     target: Target,
@@ -712,9 +1111,7 @@ def cal_vMelt(
 
     """
     if type is Choices.Collins:
-        return collins_cal_vMelt(
-            impactor, target, velocity, energy_seafloor
-        )
+        return collins_cal_vMelt(impactor, target, velocity, energy_seafloor)
 
     return 0
 
@@ -746,6 +1143,60 @@ def cal_mratio_and_mcratio(
     return 0
 
 
+def cal_mratio(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    vMelt: float = 0,
+    vCrater: float = 0,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_mratio_and_mcratio(
+            impactor, target, velocity, vMelt, vCrater, Dtr
+        )[0]
+
+    return 0
+
+
+def cal_mcratio(
+    impactor: Impactor,
+    target: Target,
+    velocity: float = 0,
+    vMelt: float = 0,
+    vCrater: float = 0,
+    Dtr: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_mratio_and_mcratio(
+            impactor, target, velocity, vMelt, vCrater, Dtr
+        )[1]
+
+    return 0
+
+
 def cal_eject_arrival(
     impactor: Impactor,
     target: Target,
@@ -840,12 +1291,7 @@ def cal_themal(
     """
     if type is Choices.Collins:
         return collins_cal_themal(
-            impactor,
-            target,
-            energy_surface,
-            altitudeBurst,
-            delta,
-            velocity,
+            impactor, target, energy_surface, altitudeBurst, delta, velocity,
         )
 
     return 0
@@ -904,6 +1350,62 @@ def cal_magnitude2(
     return 0
 
 
+def cal_eff_mag(
+    impactor: Impactor,
+    target: Target,
+    energy_seafloor: float = 0,
+    altitudeBurst: float = 0,
+    distance: float = 0,
+    surface_wave_v: float = 0,
+    delta: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_magnitude2(
+            impactor, target, altitudeBurst, energy_seafloor, delta
+        )[0]
+
+    return 0
+
+
+def cal_seismic_arrival(
+    impactor: Impactor,
+    target: Target,
+    energy_seafloor: float = 0,
+    altitudeBurst: float = 0,
+    distance: float = 0,
+    surface_wave_v: float = 0,
+    delta: float = 0,
+    type: Choices = Choices.Collins,
+) -> float:
+    """
+
+    Arguments
+    ---------
+
+
+    Returns
+    -------
+
+    """
+    if type is Choices.Collins:
+        return collins_cal_magnitude2(
+            impactor, target, altitudeBurst, energy_seafloor, delta
+        )[1]
+
+    return 0
+
+
 def cal_shock_arrival(
     impactor: Impactor,
     target: Target,
@@ -944,9 +1446,7 @@ def cal_vmax(
 
     """
     if type is Choices.Collins:
-        return collins_cal_vmax(
-            impactor, target, energy_blast, altitudeBurst
-        )
+        return collins_cal_vmax(impactor, target, energy_blast, altitudeBurst)
 
     return 0
 
@@ -1040,9 +1540,7 @@ def cal_WaveAmplitudeUpperLimit(
 
     """
     if type is Choices.Collins:
-        return collins_cal_WaveAmplitudeUpperLimit(
-            impactor, target, wdiameter
-        )
+        return collins_cal_WaveAmplitudeUpperLimit(impactor, target, wdiameter)
 
     return 0
 
@@ -1064,9 +1562,7 @@ def cal_WaveAmplitudeLowerLimit(
 
     """
     if type is Choices.Collins:
-        return collins_cal_WaveAmplitudeLowerLimit(
-            impactor, target, wdiameter
-        )
+        return collins_cal_WaveAmplitudeLowerLimit(impactor, target, wdiameter)
 
     return 0
 
@@ -1074,21 +1570,38 @@ def cal_WaveAmplitudeLowerLimit(
 def simulateImpactor(impactor: Impactor, targets: Target):
 
     # cal_energy
-    energy_disc, rec_disc, change_disc, atmos_disc, crater_disc, eject_disc, themal_disc, seismic_disc, ejecta_disc, airblast_disc, tsunami_disc = \
-        "", "", "", "", "", "", "", "", "", "", ""
+    (
+        energy_disc,
+        rec_disc,
+        change_disc,
+        atmos_disc,
+        crater_disc,
+        eject_disc,
+        themal_disc,
+        seismic_disc,
+        ejecta_disc,
+        airblast_disc,
+        tsunami_disc,
+    ) = ("", "", "", "", "", "", "", "", "", "", "")
     _kinetic_energy = kinetic_energy(impactor)
     _kinetic_energy_megatons = kinetic_energy_megatons(impactor)
     energy_disc = print_energy(_kinetic_energy, _kinetic_energy_megatons)
 
     _rec_time = rec_time(impactor)
-    print(_rec_time)
+    # print(_rec_time)
     rec_disc = print_recurrencetime(_rec_time)
 
     # atmospheric_entry
     collins_iFactor, _av, _rStrength = iFactor(impactor, targets)
-    print(collins_iFactor)
+    # print(collins_iFactor)
 
-    altitudeBU, altitudeBurst, dispersion, energy_surface, energy_megatons = 0, 0, 0, 0, 0
+    altitudeBU, altitudeBurst, dispersion, energy_surface, energy_megatons = (
+        0,
+        0,
+        0,
+        0,
+        0,
+    )
     if collins_iFactor >= 1:
         velocity = burst_velocity_at_zero(impactor, targets)
     else:
@@ -1111,7 +1624,7 @@ def simulateImpactor(impactor: Impactor, targets: Target):
 
     mwater = cal_mass_of_water(impactor, targets)
     vseafloor = cal_velocity_projectile(impactor, targets)
-    print("vseafloor", vseafloor)
+    # print("vseafloor", vseafloor)
     energy_seafloor = cal_energy_at_seafloor(impactor, targets)
     delta = cal_ePIcentral_angle(targets)
     # end_cal_energy
@@ -1142,17 +1655,33 @@ def simulateImpactor(impactor: Impactor, targets: Target):
 
     change_disc = print_change(vRatio, mratio, lratio, trot_change, pratio)
 
-    energy_megatons = energy_surface / (4.186 * 10**15)
+    energy_megatons = energy_surface / (4.186 * 10 ** 15)
     if impactor.get_mass() <= 1.5707963e12:
-        atmos_disc = print_atmospheric_entry(impactor.get_mass(), impactor.velocity, velocity, collins_iFactor, altitudeBU,
-                                             altitudeBurst, impactor.density, dispersion, impactor.theta, energy_surface, energy_megatons)
+        atmos_disc = print_atmospheric_entry(
+            impactor.get_mass(),
+            impactor.velocity,
+            velocity,
+            collins_iFactor,
+            altitudeBU,
+            altitudeBurst,
+            impactor.density,
+            dispersion,
+            impactor.theta,
+            energy_surface,
+            energy_megatons,
+        )
 
     if altitudeBurst <= 0:
         ejecta_arrival = cal_eject_arrival(impactor, targets)
 
         ejecta_thickness = cal_ejecta_thickness(impactor, targets)
-        d_frag = cal_d_frag(impactor=impactor, target=targets,
-                            cdiameter=cdiameter, altitudeBurst=altitudeBurst, Dtr=Dtr)
+        d_frag = cal_d_frag(
+            impactor=impactor,
+            target=targets,
+            cdiameter=cdiameter,
+            altitudeBurst=altitudeBurst,
+            Dtr=Dtr,
+        )
 
         if velocity >= 15:
             (
@@ -1170,36 +1699,104 @@ def simulateImpactor(impactor: Impactor, targets: Target):
 
         eff_mag, seismic_arrival = cal_magnitude2(impactor, targets)
 
-        crater_disc = print_crater(vMelt, Dtr, targets.depth, wdiameter, impactor.pdiameter, dispersion,
-                                   collins_iFactor, depthtr, mratio, mcratio, cdiameter, depthfr, brecciaThickness, velocity)
-        if targets.distance * 1000 <= Dtr/2:
-            eject_disc = print_ejecta(energy_megatons, int(log(energy_megatons)/log(10)), targets.distance,
-                                      Rf, Dtr, cdiameter, ejecta_arrival, ejecta_thickness, d_frag)
+        crater_disc = print_crater(
+            vMelt,
+            Dtr,
+            targets.depth,
+            wdiameter,
+            impactor.pdiameter,
+            dispersion,
+            collins_iFactor,
+            depthtr,
+            mratio,
+            mcratio,
+            cdiameter,
+            depthfr,
+            brecciaThickness,
+            velocity,
+        )
+        if targets.distance * 1000 <= Dtr / 2:
+            eject_disc = print_ejecta(
+                energy_megatons,
+                int(log(energy_megatons) / log(10)),
+                targets.distance,
+                Rf,
+                Dtr,
+                cdiameter,
+                ejecta_arrival,
+                ejecta_thickness,
+                d_frag,
+            )
             return
 
-        themal_disc = print_thermal(velocity, no_radiation_, max_rad_time_, targets.distance, Rf,
-                                    h, thermal_power_, thermal_exposure_, irradiation_time_)
+        themal_disc = print_thermal(
+            velocity,
+            no_radiation_,
+            max_rad_time_,
+            targets.distance,
+            Rf,
+            h,
+            thermal_power_,
+            thermal_exposure_,
+            irradiation_time_,
+        )
         seismic_disc = print_seismic(magnitude, seismic_arrival)
-        ejecta_disc = print_ejecta(energy_megatons, int(log(energy_megatons)/log(10)), targets.distance,
-                                   Rf, Dtr, cdiameter, ejecta_arrival, ejecta_thickness, d_frag)
+        ejecta_disc = print_ejecta(
+            energy_megatons,
+            int(log(energy_megatons) / log(10)),
+            targets.distance,
+            Rf,
+            Dtr,
+            cdiameter,
+            ejecta_arrival,
+            ejecta_thickness,
+            d_frag,
+        )
 
     # Compute the effects of the airblast and print
     shock_arrival = cal_shock_arrival(impactor, targets)
     vmax, opressure = cal_vmax(impactor, targets)
     shock_damage = cal_shock_damage(
-        impactor=impactor, target=targets, opressure=opressure, vmax=vmax)
+        impactor=impactor, target=targets, opressure=opressure, vmax=vmax
+    )
     dec_level = cal_dec_level(impactor, targets)
-    airblast_disc = print_airblast(opressure, vmax, shock_arrival,
-                                   targets.distance, altitudeBurst, dec_level, shock_damage)
+    airblast_disc = print_airblast(
+        opressure,
+        vmax,
+        shock_arrival,
+        targets.distance,
+        altitudeBurst,
+        dec_level,
+        shock_damage,
+    )
 
     # Compute the tsunami amplitude if water layer present
     if targets.depth > 0:
         TsunamiArrivalTime = cal_TsunamiArrivalTime(impactor, targets)
         WaveAmplitudeUpperLimit = cal_WaveAmplitudeUpperLimit(
-            impactor, targets)
+            impactor, targets
+        )
         WaveAmplitudeLowerLimit = cal_WaveAmplitudeLowerLimit(
-            impactor, targets)
-        tsunami_disc = print_tsunami(targets.distance, wdiameter, TsunamiArrivalTime,
-                                     WaveAmplitudeLowerLimit, WaveAmplitudeUpperLimit)
+            impactor, targets
+        )
+        tsunami_disc = print_tsunami(
+            targets.distance,
+            wdiameter,
+            TsunamiArrivalTime,
+            WaveAmplitudeLowerLimit,
+            WaveAmplitudeUpperLimit,
+        )
 
-    return energy_disc, rec_disc, change_disc, atmos_disc, crater_disc, eject_disc, themal_disc, seismic_disc, ejecta_disc, airblast_disc, tsunami_disc
+    return (
+        energy_disc,
+        rec_disc,
+        change_disc,
+        atmos_disc,
+        crater_disc,
+        eject_disc,
+        themal_disc,
+        seismic_disc,
+        ejecta_disc,
+        airblast_disc,
+        tsunami_disc,
+    )
