@@ -179,8 +179,8 @@ class Target:
     def set_distance(self, distance):
         if not numeric_checker(distance):
             raise ValueError("distance must be numeric")
-        if not positive_checker(distance):
-            raise ValueError("distance must be positive")
+        # if not positive_checker(distance):
+        #     raise ValueError("distance must be positive")
 
         self.distance = distance
 
@@ -196,9 +196,7 @@ class Target:
         if not numeric_checker(seefloor_density):
             raise ValueError("seefloor_density must be numeric")
         if not positive_checker(seefloor_density):
-            raise ValueError(
-                "seefloor_density must be seefloor_densitysitive"
-            )
+            raise ValueError("seefloor_density must be seefloor_densitysitive")
 
         self.seefloor_density = seefloor_density
 
