@@ -1,5 +1,8 @@
+import numpy
+
+
 def numeric_checker(num) -> bool:
-    if type(num) == int or type(num) == float:
+    if type(num) == int or type(num) == float or type(num) == numpy.float64:
         return True
     return False
 
